==> open-cluster-management-cluster-model-6.8.1-sources.jar: io/fabric8/openclustermanagement/api/model/cluster/v1/ClientConfigFluent.java <==
package io.fabric8.openclustermanagement.api.model.cluster.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ClientConfigFluent<A extends ClientConfigFluent<A>> extends BaseFluent<A>{
  public ClientConfigFluent() {
  }
  public ClientConfigFluent(ClientConfig instance) {
    instance = (instance != null ? instance : new ClientConfig());

    if (instance != null) {
      this.withCaBundle(instance.getCaBundle());
      this.withUrl(instance.getUrl());
      this.withCaBundle(instance.getCaBundle());
      this.withUrl(instance.getUrl());
    }
  }
  private String caBundle;
  private String url;
  public String getCaBundle() {
    return this.caBundle;
  }
  public A withCaBundle(String caBundle) {
    this.caBundle=caBundle; return (A) this;
  }
  public boolean hasCaBundle() {
    return this.caBundle != null;
  }
  public String getUrl() {
    return this.url;
  }
  public A withUrl(String url) {
    this.url=url; return (A) this;
  }
  public boolean hasUrl() {
    return this.url != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ClientConfigFluent that = (ClientConfigFluent) o;
    if (!java.util.Objects.equals(caBundle, that.caBundle)) return false;

    if (!java.util.Objects.equals(url, that.url)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(caBundle,  url,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (caBundle != null) { sb.append("caBundle:"); sb.append(caBundle + ","); }
    if (url != null) { sb.append("url:"); sb.append(url); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> open-cluster-management-cluster-model-6.9.0-sources.jar: io/fabric8/openclustermanagement/api/model/cluster/v1/ClientConfigFluent.java <==
package io.fabric8.openclustermanagement.api.model.cluster.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ClientConfigFluent<A extends ClientConfigFluent<A>> extends BaseFluent<A>{
  public ClientConfigFluent() {
  }
  
  public ClientConfigFluent(ClientConfig instance) {
    this.copyInstance(instance);
  }
  private String caBundle;
  private String url;
  
  protected void copyInstance(ClientConfig instance) {
    instance = (instance != null ? instance : new ClientConfig());
  
    if (instance != null) {
        this.withCaBundle(instance.getCaBundle());
        this.withUrl(instance.getUrl());
        this.withCaBundle(instance.getCaBundle());
        this.withUrl(instance.getUrl());
      }
  }
  
  public String getCaBundle() {
    return this.caBundle;
  }
  
  public A withCaBundle(String caBundle) {
    this.caBundle=caBundle; return (A) this;
  }
  
  public boolean hasCaBundle() {
    return this.caBundle != null;
  }
  
  public String getUrl() {
    return this.url;
  }
  
  public A withUrl(String url) {
    this.url=url; return (A) this;
  }
  
  public boolean hasUrl() {
    return this.url != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ClientConfigFluent that = (ClientConfigFluent) o;
    if (!java.util.Objects.equals(caBundle, that.caBundle)) return false;
  
    if (!java.util.Objects.equals(url, that.url)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(caBundle,  url,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (caBundle != null) { sb.append("caBundle:"); sb.append(caBundle + ","); }
    if (url != null) { sb.append("url:"); sb.append(url); }
    sb.append("}");
    return sb.toString();
  }
  

}
